#line 2 "scantl.cc"
#include "config.h"
/* Flex 2.6.4's test for <inttypes.h> relies on __STDC_VERSION__
   which is undefined in C++.   So without that, it will define
   its own integer types, including a broken SIZE_MAX definition.
   So let's define __STDC_VERSION__ to make sure <inttypes.h> gets
   included. */
#if HAVE_INTTYPES_H && !(defined __STDC_VERSION__)
#  define __STDC_VERSION__ 199901L
#endif

#line 13 "scantl.cc"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer tlyy_create_buffer
#define yy_delete_buffer tlyy_delete_buffer
#define yy_scan_buffer tlyy_scan_buffer
#define yy_scan_string tlyy_scan_string
#define yy_scan_bytes tlyy_scan_bytes
#define yy_init_buffer tlyy_init_buffer
#define yy_flush_buffer tlyy_flush_buffer
#define yy_load_buffer_state tlyy_load_buffer_state
#define yy_switch_to_buffer tlyy_switch_to_buffer
#define yypush_buffer_state tlyypush_buffer_state
#define yypop_buffer_state tlyypop_buffer_state
#define yyensure_buffer_stack tlyyensure_buffer_stack
#define yy_flex_debug tlyy_flex_debug
#define yyin tlyyin
#define yyleng tlyyleng
#define yylex tlyylex
#define yylineno tlyylineno
#define yyout tlyyout
#define yyrestart tlyyrestart
#define yytext tlyytext
#define yywrap tlyywrap
#define yyalloc tlyyalloc
#define yyrealloc tlyyrealloc
#define yyfree tlyyfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define tlyy_create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer tlyy_create_buffer
#endif

#ifdef yy_delete_buffer
#define tlyy_delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer tlyy_delete_buffer
#endif

#ifdef yy_scan_buffer
#define tlyy_scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer tlyy_scan_buffer
#endif

#ifdef yy_scan_string
#define tlyy_scan_string_ALREADY_DEFINED
#else
#define yy_scan_string tlyy_scan_string
#endif

#ifdef yy_scan_bytes
#define tlyy_scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes tlyy_scan_bytes
#endif

#ifdef yy_init_buffer
#define tlyy_init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer tlyy_init_buffer
#endif

#ifdef yy_flush_buffer
#define tlyy_flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer tlyy_flush_buffer
#endif

#ifdef yy_load_buffer_state
#define tlyy_load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state tlyy_load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define tlyy_switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer tlyy_switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define tlyypush_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state tlyypush_buffer_state
#endif

#ifdef yypop_buffer_state
#define tlyypop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state tlyypop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define tlyyensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack tlyyensure_buffer_stack
#endif

#ifdef yylex
#define tlyylex_ALREADY_DEFINED
#else
#define yylex tlyylex
#endif

#ifdef yyrestart
#define tlyyrestart_ALREADY_DEFINED
#else
#define yyrestart tlyyrestart
#endif

#ifdef yylex_init
#define tlyylex_init_ALREADY_DEFINED
#else
#define yylex_init tlyylex_init
#endif

#ifdef yylex_init_extra
#define tlyylex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra tlyylex_init_extra
#endif

#ifdef yylex_destroy
#define tlyylex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy tlyylex_destroy
#endif

#ifdef yyget_debug
#define tlyyget_debug_ALREADY_DEFINED
#else
#define yyget_debug tlyyget_debug
#endif

#ifdef yyset_debug
#define tlyyset_debug_ALREADY_DEFINED
#else
#define yyset_debug tlyyset_debug
#endif

#ifdef yyget_extra
#define tlyyget_extra_ALREADY_DEFINED
#else
#define yyget_extra tlyyget_extra
#endif

#ifdef yyset_extra
#define tlyyset_extra_ALREADY_DEFINED
#else
#define yyset_extra tlyyset_extra
#endif

#ifdef yyget_in
#define tlyyget_in_ALREADY_DEFINED
#else
#define yyget_in tlyyget_in
#endif

#ifdef yyset_in
#define tlyyset_in_ALREADY_DEFINED
#else
#define yyset_in tlyyset_in
#endif

#ifdef yyget_out
#define tlyyget_out_ALREADY_DEFINED
#else
#define yyget_out tlyyget_out
#endif

#ifdef yyset_out
#define tlyyset_out_ALREADY_DEFINED
#else
#define yyset_out tlyyset_out
#endif

#ifdef yyget_leng
#define tlyyget_leng_ALREADY_DEFINED
#else
#define yyget_leng tlyyget_leng
#endif

#ifdef yyget_text
#define tlyyget_text_ALREADY_DEFINED
#else
#define yyget_text tlyyget_text
#endif

#ifdef yyget_lineno
#define tlyyget_lineno_ALREADY_DEFINED
#else
#define yyget_lineno tlyyget_lineno
#endif

#ifdef yyset_lineno
#define tlyyset_lineno_ALREADY_DEFINED
#else
#define yyset_lineno tlyyset_lineno
#endif

#ifdef yywrap
#define tlyywrap_ALREADY_DEFINED
#else
#define yywrap tlyywrap
#endif

#ifdef yyalloc
#define tlyyalloc_ALREADY_DEFINED
#else
#define yyalloc tlyyalloc
#endif

#ifdef yyrealloc
#define tlyyrealloc_ALREADY_DEFINED
#else
#define yyrealloc tlyyrealloc
#endif

#ifdef yyfree
#define tlyyfree_ALREADY_DEFINED
#else
#define yyfree tlyyfree
#endif

#ifdef yytext
#define tlyytext_ALREADY_DEFINED
#else
#define yytext tlyytext
#endif

#ifdef yyleng
#define tlyyleng_ALREADY_DEFINED
#else
#define yyleng tlyyleng
#endif

#ifdef yyin
#define tlyyin_ALREADY_DEFINED
#else
#define yyin tlyyin
#endif

#ifdef yyout
#define tlyyout_ALREADY_DEFINED
#else
#define yyout tlyyout
#endif

#ifdef yy_flex_debug
#define tlyy_flex_debug_ALREADY_DEFINED
#else
#define yy_flex_debug tlyy_flex_debug
#endif

#ifdef yylineno
#define tlyylineno_ALREADY_DEFINED
#else
#define yylineno tlyylineno
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len  );

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define tlyywrap() (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;
#define YY_NUM_RULES 87
#define YY_END_OF_BUFFER 88
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[286] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    2,    2,    0,    0,   88,   86,   72,   72,
       22,   77,   86,   52,    8,   17,   36,   50,   86,   73,
       86,   21,   20,   35,   34,   86,   86,   62,   63,   69,
       65,   73,   64,   68,   66,   86,   86,   53,   73,   73,
       12,   50,   19,   86,   86,   86,   75,   62,   63,   69,
       65,   75,   64,   68,   66,   75,   75,   11,   11,   11,
        9,   10,   11,   16,   16,   16,   16,   13,   15,   86,
       49,   48,   86,   86,   47,   45,   86,   86,   78,   85,
       84,    2,    2,    5,    5,    4,    3,   83,   72,   72,

       72,   79,   83,   86,   72,    0,   51,   66,    0,   54,
       73,    1,    0,    0,   62,   70,   71,   54,    0,   74,
        0,   60,    0,   61,   73,    0,   59,   39,    0,    0,
        0,   43,   63,    0,   50,   73,   73,   73,    0,    0,
        0,    0,   18,   22,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,   75,   75,   75,   75,
       75,   11,   11,    1,   16,   16,    1,    0,   14,   46,
       48,   47,    0,   85,    2,    2,    5,    6,    6,    5,
        4,    4,    7,    3,   83,   72,   72,   72,   72,   72,
        1,   82,   24,   29,    0,   55,   55,    0,    0,    0,

       74,    0,   57,   58,   73,   56,   37,   38,    0,   44,
       42,    0,    0,    0,    0,    0,    0,   73,   73,   53,
        0,   30,   32,    0,    0,    0,   30,   53,   67,   32,
       75,   76,   75,   75,   75,   53,   49,   72,   72,   72,
       72,   25,    0,    0,    0,   31,   33,    0,    0,    0,
        0,   20,   40,   41,    0,    0,    0,    0,   73,   73,
       20,   75,   75,   26,   28,   27,   21,   21,   73,   21,
       75,   26,   73,   75,   73,   75,   73,   75,   73,   75,
       73,   75,   23,   23,    0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    5,    6,    7,    8,    1,    9,    1,   10,
       11,   12,   13,   14,   15,   16,   17,   18,   19,   20,
       20,   20,   20,   20,   20,   20,   20,   21,   22,   23,
       24,   25,    1,    1,   26,   27,   27,   27,   28,   29,
       30,   27,   27,   27,   27,   31,   32,   27,   27,   27,
       27,   33,   34,   35,   36,   37,   38,   39,   27,   27,
       40,   41,   42,   43,   44,    1,   45,   27,   46,   27,

       47,   48,   27,   49,   50,   27,   27,   31,   51,   52,
       53,   27,   27,   54,   55,   56,   57,   27,   27,   58,
       27,   27,   59,   60,   61,   62,    1,    1,    1,    1,
        1,   63,   64,   65,   66,   67,    1,   68,   69,    1,
       70,    1,    1,    1,    1,   71,   72,   73,   74,   75,
       76,    1,   77,    1,    1,   78,    1,    1,   79,    1,
       80,   81,    1,   82,    1,   83,   84,   85,   86,   87,
        1,   88,    1,    1,   89,    1,    1,    1,    1,    1,
        1,   90,    1,    1,   91,    1,   92,    1,    1,    1,
        1,    1,    1,   93,    1,    1,    1,    1,    1,    1,

        1,    1,    1,   94,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,   95,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[96] =
    {   0,
        1,    1,    2,    3,    1,    4,    1,    1,    1,    5,
        5,    6,    1,    1,    1,    7,    6,    7,    7,    7,
        1,    1,    1,    1,    1,    7,    7,    7,    8,    8,
        7,    7,    7,    7,    7,    7,    7,    7,    8,    1,
        4,    1,    1,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    9,    1,
        9,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1

    } ;

static const flex_int16_t yy_base[304] =
    {   0,
        0,    0,   80,    0,  137,  140,  156,  159,  219,  274,
      329,    0,  162,  165,  184,  189,  774,  775,   95,   98,
      775,  775,  766,  763,  760,  775,  775,  775,  130,    0,
      108,  775,  775,  775,  775,  156,  178,  240,  244,    0,
        0,  145,    0,    0,  294,  192,  753,  775,  144,  716,
      775,  226,  151,  680,   40,  323,    0,  297,  249,  775,
      775,  165,  775,  775,  268,  223,  714,    0,  119,  181,
      775,  775,  754,    0,  206,  252,  753,  775,  170,  722,
      775,  775,  747,  750,  284,  775,  709,  707,  775,    0,
        0,    0,  303,  307,  315,  214,  747,    0,  323,  336,

      345,  775,  746,    0,  348,  388,  775,  775,  732,  775,
        0,  744,  187,  730,  259,  775,  775,  775,  410,    0,
      723,  711,  413,  697,  175,  416,  690,  689,  688,  242,
      216,  775,  329,  135,  775,  691,  667,  659,  378,  687,
      331,  367,  775,  775,  350,  249,  345,  633,  641,  633,
      607,  356,  553,  238,  567,  552,  397,  405,  408,  413,
      425,    0,  455,  617,    0,  466,  616,  399,  775,  775,
      775,  453,  578,    0,    0,  472,  478,  481,  484,  487,
      324,  434,  775,  612,    0,  490,  493,  496,  499,  502,
      609,  775,  489,  358,  592,  775,  775,  495,  588,  446,

        0,  406,  775,  775,  485,  775,  775,  775,  584,  775,
      566,  557,  499,  565,  450,  517,  494,  483,  527,    0,
      555,  775,  775,  508,  474,  375,  775,  775,  775,  775,
      489,    0,  505,  492,  507,  510,  775,  539,  551,  554,
      557,  545,  488,  485,  498,  775,  775,  392,  389,  387,
      520,    0,  775,  775,  424,  338,  323,  460,  538,  287,
      539,  542,  544,  557,  775,  775,  775,    0,  271,  557,
      562,  575,  230,  568,  220,  573,  189,  575,  106,  581,
       97,  586,    0,  593,  775,  635,  644,  653,  662,  671,
      674,   98,  682,  691,  693,  701,  710,  719,  728,  737,

      740,  742,  744
    } ;

static const flex_int16_t yy_def[304] =
    {   0,
      285,    1,    1,    3,  286,  286,  287,  287,  288,  288,
      288,   11,  289,  289,  290,  290,  285,  285,  285,  285,
      285,  285,  285,  285,  285,  285,  285,  285,  285,  291,
      285,  285,  285,  285,  285,  285,  285,  285,  285,  291,
      291,  291,  291,  291,  285,  285,  285,  285,  291,  291,
      285,  285,  285,  285,  285,  285,  292,  285,  285,  285,
      285,  292,  285,  285,  285,  292,  292,  293,  293,  293,
      285,  285,  293,  294,  294,  294,  294,  285,  285,  285,
      285,  285,  285,  285,  285,  285,  285,  285,  285,  295,
      295,  296,  296,  285,  285,  297,  298,  299,  299,  285,

      285,  285,  299,  300,  285,  285,  285,  285,  285,  285,
      291,  285,  285,  285,  285,  285,  285,  285,  285,  301,
      285,  285,  285,  285,  291,  285,  285,  285,  285,  285,
      285,  285,  285,  285,  285,  291,  291,  291,  285,  285,
      285,  285,  285,  285,  285,  285,  285,  285,  285,  285,
      285,  285,  285,  285,  285,  285,  302,  302,  302,  302,
      302,  293,  293,  293,  294,  294,  294,  285,  285,  285,
      285,  285,  285,  295,  296,  296,  285,  285,  285,  285,
      297,  297,  285,  298,  299,  299,  285,  285,  285,  285,
      299,  285,  285,  285,  285,  285,  285,  285,  285,  285,

      301,  285,  285,  285,  291,  285,  285,  285,  285,  285,
      285,  285,  285,  285,  285,  285,  285,  291,  291,  291,
      285,  285,  285,  285,  285,  285,  285,  285,  285,  285,
      302,  303,  302,  302,  302,  302,  285,  285,  285,  285,
      285,  285,  285,  285,  285,  285,  285,  285,  285,  285,
      285,  291,  285,  285,  285,  285,  285,  285,  291,  291,
      302,  302,  302,  285,  285,  285,  285,  291,  291,  302,
      302,  285,  291,  302,  291,  302,  291,  302,  291,  302,
      291,  302,  291,  302,    0,  285,  285,  285,  285,  285,
      285,  285,  285,  285,  285,  285,  285,  285,  285,  285,

      285,  285,  285
    } ;

static const flex_int16_t yy_nxt[871] =
    {   0,
       18,   19,   20,   19,   21,   22,   23,   18,   24,   25,
       26,   27,   28,   18,   29,   30,   31,   32,   33,   18,
       34,   35,   36,   37,   18,   30,   30,   30,   38,   39,
       30,   40,   41,   30,   42,   43,   41,   44,   45,   46,
       47,   18,   48,   30,   30,   30,   30,   49,   30,   30,
       30,   30,   30,   30,   30,   42,   30,   50,   51,   52,
       53,   21,   18,   18,   18,   18,   18,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,
       18,   18,   54,   55,   56,   57,  105,  105,  105,  105,

      105,  105,  116,  116,  157,   57,   57,   57,   58,   59,
       57,   60,   61,   57,   62,   63,   61,   64,   65,  112,
      163,  163,  163,   57,   57,   57,   57,   66,   57,   57,
       57,   57,   57,   57,   57,   62,   57,   67,   69,   70,
       69,   69,   70,   69,  109,  283,   71,   72,  107,   71,
       72,  281,  142,   73,  110,  143,   73,   75,   76,   75,
       75,   76,   75,   93,   94,   95,   93,   94,   95,  136,
      113,  168,   77,   96,  169,   77,   96,  125,   97,  114,
      115,   97,  163,  163,  163,   99,  100,  101,  136,  102,
       99,  100,  101,  137,  102,  116,  117,  158,  125,  216,

      103,  195,  118,  128,  129,  103,  130,  166,  166,  166,
      205,  196,  131,  217,   78,  132,   79,   78,  158,   79,
       19,   20,   19,   80,  104,  182,   81,  211,  212,  104,
      183,  205,   82,  133,   83,   84,   85,   85,   85,   82,
      139,  119,  119,  119,  279,  123,  123,  123,  159,  140,
      123,  123,  123,  166,  166,  166,  209,  120,  120,  120,
       86,  120,  120,  120,  277,  121,  210,  159,   87,  126,
      126,  126,  160,  198,   88,   19,   20,   19,   80,  122,
      275,   81,  199,  124,  121,  135,  134,   82,  124,   83,
       84,   85,   85,   85,   82,  126,  126,  126,  119,  119,

      119,  172,  172,  172,  176,  105,  105,  127,  105,  177,
      178,  120,  120,  120,  273,   86,  105,  179,  180,  118,
      141,  197,  121,   87,  186,  105,  105,  110,  118,   88,
       19,   20,   19,  127,   89,  285,  122,  105,  187,  188,
      285,  121,  269,  213,   90,   84,  105,  189,  190,  105,
      105,  105,  214,  200,   90,   90,   90,   91,   91,   90,
       91,   91,   90,   90,   91,   91,   91,   91,  142,  243,
      244,  143,   90,   90,   90,   91,   91,   90,   91,   90,
       90,   90,   90,   90,   91,   90,   90,  145,  146,  147,
      148,  149,  221,  230,  150,  224,  225,  151,  152,  153,

      168,  154,  222,  169,  155,  193,  193,  193,  227,  226,
      156,  119,  119,  119,  123,  123,  123,  126,  126,  126,
      110,  115,  196,  215,  108,  232,  232,  194,  107,  135,
      107,  135,  227,  232,  232,  232,  232,  232,  234,  251,
      233,  232,  232,  232,  108,  182,  232,  133,  227,  122,
      183,  232,  124,  232,  232,  127,  163,  163,  163,  247,
      251,  233,  246,  232,  222,  223,  235,  166,  166,  166,
      172,  172,  172,  176,  105,  105,  246,  247,  236,  105,
      177,  105,  105,  238,  105,  105,  105,  239,  105,  105,
      180,  186,  105,  105,  105,  187,  105,  105,  240,  105,

      105,  105,  241,  105,  105,  190,  242,  242,  242,  245,
      248,  249,  252,  255,  256,  257,  259,  232,  232,  246,
      232,  232,  246,  227,  250,  262,  266,  232,  258,  265,
      232,  252,  261,  232,  232,  232,  232,  259,  232,  232,
      105,  105,  178,  232,  223,  232,  262,  267,  232,  227,
      230,  261,  105,  179,  105,  105,  105,  188,  105,  189,
      105,  263,  264,  264,  264,  268,  267,  232,  232,  270,
      232,  232,  232,  232,  272,  272,  272,  232,  222,  222,
      232,  260,  232,  210,  268,  232,  232,  210,  270,  230,
      232,  232,  272,  272,  272,  232,  232,  232,  254,  271,

      232,  232,  232,  232,  232,  274,  232,  253,  210,  232,
      232,  232,  247,  232,  232,  232,  196,  278,  276,  232,
      191,  232,  232,  285,  232,  237,  282,  167,  164,  133,
      280,  232,  230,  115,  284,   68,   68,   68,   68,   68,
       68,   68,   68,   68,   74,   74,   74,   74,   74,   74,
       74,   74,   74,   18,   18,   18,   18,   18,   18,   18,
       18,   18,   92,   92,   92,   92,   92,   92,   92,   92,
       92,   98,   98,   98,   98,   98,   98,   98,   98,   98,
      111,  111,  162,  162,  162,  162,  133,  162,  162,  162,
      162,  165,  165,  165,  165,  165,  165,  165,  165,  174,

      174,  175,  229,  115,  175,  175,  228,  175,  175,  175,
      181,  223,  220,  181,  181,  181,  181,  181,  181,  184,
      219,  218,  184,  184,  184,  184,  184,  184,  185,  208,
      207,  206,  185,  185,  185,  185,  185,  192,  204,  192,
      192,  192,  192,  192,  192,  192,  201,  201,  231,  231,
      232,  232,  203,  202,  197,  112,  110,  191,  112,  171,
      173,  112,  171,  170,  167,  164,  161,  144,  138,  135,
      108,  107,  106,  285,   17,  285,  285,  285,  285,  285,
      285,  285,  285,  285,  285,  285,  285,  285,  285,  285,
      285,  285,  285,  285,  285,  285,  285,  285,  285,  285,

      285,  285,  285,  285,  285,  285,  285,  285,  285,  285,
      285,  285,  285,  285,  285,  285,  285,  285,  285,  285,
      285,  285,  285,  285,  285,  285,  285,  285,  285,  285,
      285,  285,  285,  285,  285,  285,  285,  285,  285,  285,
      285,  285,  285,  285,  285,  285,  285,  285,  285,  285,
      285,  285,  285,  285,  285,  285,  285,  285,  285,  285,
      285,  285,  285,  285,  285,  285,  285,  285,  285,  285
    } ;

static const flex_int16_t yy_chk[871] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    3,   19,   19,   19,   20,

       20,   20,   55,   55,  292,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,   31,
       69,   69,   69,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    5,    5,
        5,    6,    6,    6,   29,  281,    5,    5,   31,    6,
        6,  279,   53,    5,   29,   53,    6,    7,    7,    7,
        8,    8,    8,   13,   13,   13,   14,   14,   14,   49,
       36,   79,    7,   13,   79,    8,   14,   42,   13,   36,
       36,   14,   70,   70,   70,   15,   15,   15,   49,   15,
       16,   16,   16,   49,   16,   37,   37,   62,   42,  134,

       15,  113,   37,   46,   46,   16,   46,   75,   75,   75,
      125,  113,   46,  134,    7,   46,    7,    8,   62,    8,
        9,    9,    9,    9,   15,   96,    9,  131,  131,   16,
       96,  125,    9,   46,    9,    9,    9,    9,    9,    9,
       52,   38,   38,   38,  277,   39,   39,   39,   66,   52,
       59,   59,   59,   76,   76,   76,  130,   38,   38,   38,
        9,   39,   39,   39,  275,   38,  130,   66,    9,   65,
       65,   65,   66,  115,    9,   10,   10,   10,   10,   38,
      273,   10,  115,   39,   38,   52,   46,   10,   59,   10,
       10,   10,   10,   10,   10,   45,   45,   45,   58,   58,

       58,   85,   85,   85,   93,   93,   93,   65,   94,   94,
       94,   45,   45,   45,  269,   10,   95,   95,   95,  146,
       52,  146,   58,   10,   99,   99,   99,  154,  154,   10,
       11,   11,   11,   45,   11,  181,   58,  100,  100,  100,
      181,   58,  260,  133,   11,   11,  101,  101,  101,  105,
      105,  105,  133,  115,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,  142,  194,
      194,  142,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   56,   56,   56,
       56,   56,  139,  257,   56,  141,  141,   56,   56,   56,

      168,   56,  139,  168,   56,  106,  106,  106,  256,  141,
       56,  119,  119,  119,  123,  123,  123,  126,  126,  126,
      145,  152,  145,  133,  152,  157,  157,  106,  147,  147,
      147,  147,  145,  158,  158,  157,  159,  159,  159,  202,
      158,  160,  160,  158,  152,  182,  159,  152,  255,  119,
      182,  160,  123,  161,  161,  126,  163,  163,  163,  249,
      202,  158,  248,  161,  226,  226,  160,  166,  166,  166,
      172,  172,  172,  176,  176,  176,  250,  250,  161,  177,
      177,  177,  178,  178,  178,  179,  179,  179,  180,  180,
      180,  186,  186,  186,  187,  187,  187,  188,  188,  188,

      189,  189,  189,  190,  190,  190,  193,  193,  193,  198,
      200,  200,  205,  213,  215,  215,  218,  231,  231,  198,
      234,  234,  245,  213,  200,  234,  244,  231,  215,  243,
      234,  205,  233,  233,  233,  235,  235,  218,  236,  236,
      238,  238,  238,  233,  225,  235,  234,  251,  236,  258,
      258,  233,  239,  239,  239,  240,  240,  240,  241,  241,
      241,  235,  242,  242,  242,  259,  251,  261,  261,  262,
      262,  262,  263,  263,  264,  264,  264,  261,  224,  221,
      262,  219,  263,  217,  259,  270,  270,  216,  262,  214,
      271,  271,  272,  272,  272,  270,  274,  274,  212,  263,

      271,  276,  276,  278,  278,  271,  274,  211,  209,  280,
      280,  276,  199,  278,  282,  282,  195,  276,  274,  280,
      191,  284,  284,  184,  282,  173,  280,  167,  164,  156,
      278,  284,  155,  153,  282,  286,  286,  286,  286,  286,
      286,  286,  286,  286,  287,  287,  287,  287,  287,  287,
      287,  287,  287,  288,  288,  288,  288,  288,  288,  288,
      288,  288,  289,  289,  289,  289,  289,  289,  289,  289,
      289,  290,  290,  290,  290,  290,  290,  290,  290,  290,
      291,  291,  293,  293,  293,  293,  151,  293,  293,  293,
      293,  294,  294,  294,  294,  294,  294,  294,  294,  295,

      295,  296,  150,  149,  296,  296,  148,  296,  296,  296,
      297,  140,  138,  297,  297,  297,  297,  297,  297,  298,
      137,  136,  298,  298,  298,  298,  298,  298,  299,  129,
      128,  127,  299,  299,  299,  299,  299,  300,  124,  300,
      300,  300,  300,  300,  300,  300,  301,  301,  302,  302,
      303,  303,  122,  121,  114,  112,  109,  103,   97,   88,
       87,   84,   83,   80,   77,   73,   67,   54,   50,   47,
       25,   24,   23,   17,  285,  285,  285,  285,  285,  285,
      285,  285,  285,  285,  285,  285,  285,  285,  285,  285,
      285,  285,  285,  285,  285,  285,  285,  285,  285,  285,

      285,  285,  285,  285,  285,  285,  285,  285,  285,  285,
      285,  285,  285,  285,  285,  285,  285,  285,  285,  285,
      285,  285,  285,  285,  285,  285,  285,  285,  285,  285,
      285,  285,  285,  285,  285,  285,  285,  285,  285,  285,
      285,  285,  285,  285,  285,  285,  285,  285,  285,  285,
      285,  285,  285,  285,  285,  285,  285,  285,  285,  285,
      285,  285,  285,  285,  285,  285,  285,  285,  285,  285
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "scantl.ll"
/* -*- coding: utf-8 -*-
** Copyright (C) 2010-2015, 2017-2019, 2021-2022, Laboratoire de
** Recherche et Développement de l'Epita (LRDE).
** Copyright (C) 2003, 2004 Laboratoire d'Informatique de Paris 6
** (LIP6), département Systèmes Répartis Coopératifs (SRC), Université
** Pierre et Marie Curie.
**
** This file is part of Spot, a model checking library.
**
** Spot is free software; you can redistribute it and/or modify it
** under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 3 of the License, or
** (at your option) any later version.
**
** Spot is distributed in the hope that it will be useful, but WITHOUT
** ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
** or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
** License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#line 41 "scantl.ll"
#include <cstdlib>
#include <string>

#include <spot/parsetl/parsedecl.hh>
#include "spot/priv/trim.hh"
#include "spot/tl/formula.hh"

#define YY_USER_ACTION \
  yylloc->columns(yyleng);

static int start_token = 0;
static int parent_level = 0;
static bool missing_parent = false;
static bool lenient_mode = false;
static int orig_cond = 0;
static unsigned comment_level = 0;

typedef tlyy::parser::token token;

#line 1050 "scantl.cc"

#line 1052 "scantl.cc"

#define INITIAL 0
#define not_prop 1
#define in_par 2
#define in_bra 3
#define sqbracket 4
#define lbt 5
#define in_COMMENT 6
#define in_STRING 7

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			int yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
    static void yyunput ( int c, char *buf_ptr  );
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif

#endif

        static int yy_start_stack_ptr = 0;
        static int yy_start_stack_depth = 0;
        static int *yy_start_stack = NULL;
    
    static void yy_push_state ( int _new_state );
    
    static void yy_pop_state ( void );
    
    static int yy_top_state ( void );
    
/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
#line 83 "scantl.ll"



#line 87 "scantl.ll"
  if (start_token)
    {
      int t = start_token;
      start_token = 0;
      return t;
    }
  yylloc->step();
  std::string s;


#line 1301 "scantl.cc"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 286 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 285 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 97 "scantl.ll"
{
			  if (YY_START != in_COMMENT)
			    {
                              orig_cond = YY_START;
                              BEGIN(in_COMMENT);
			      comment_level = 0;
			    }
			  ++comment_level;
			}
	YY_BREAK

case 2:
YY_RULE_SETUP
#line 107 "scantl.ll"
continue;
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 108 "scantl.ll"
continue;
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 109 "scantl.ll"
continue;
	YY_BREAK
case 5:
/* rule 5 can match eol */
YY_RULE_SETUP
#line 110 "scantl.ll"
yylloc->lines(yyleng); yylloc->end.column = 1;
	YY_BREAK
case 6:
/* rule 6 can match eol */
YY_RULE_SETUP
#line 111 "scantl.ll"
yylloc->lines(yyleng / 2); yylloc->end.column = 1;
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 112 "scantl.ll"
if (--comment_level == 0) BEGIN(orig_cond);
	YY_BREAK
case YY_STATE_EOF(in_COMMENT):
#line 113 "scantl.ll"
{
                           BEGIN(orig_cond);
                           error_list.push_back(
			     spot::one_parse_error(*yylloc,
			       "unclosed comment"));
			   return 0;
                        }
	YY_BREAK

case 8:
YY_RULE_SETUP
#line 122 "scantl.ll"
{
				  if (!lenient_mode)
                                    {
				      BEGIN(0);
				      return token::PAR_OPEN;
                                    }
                                  /* Parse any (...) block as a single block,
				     taking care of nested parentheses.  The
				     parser will then try to parse this block
				     recursively.  */
                                  BEGIN(in_par);
                                  parent_level = 1;
				  yylval->str = new std::string();
                                }
	YY_BREAK

case 9:
YY_RULE_SETUP
#line 137 "scantl.ll"
{
				  ++parent_level;
				  yylval->str->append(yytext, yyleng);
				}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 141 "scantl.ll"
{
				  if (--parent_level)
				    {
                                      yylval->str->append(yytext, yyleng);
				    }
				  else
				    {
                                      BEGIN(not_prop);
				      spot::trim(*yylval->str);
				      return token::PAR_BLOCK;
				    }
				}
	YY_BREAK
case 11:
/* rule 11 can match eol */
YY_RULE_SETUP
#line 153 "scantl.ll"
yylval->str->append(yytext, yyleng);
	YY_BREAK
case YY_STATE_EOF(in_par):
#line 154 "scantl.ll"
{
				  unput(')');
				  if (!missing_parent)
                                    error_list.push_back(
				      spot::one_parse_error(*yylloc,
 					"missing closing parenthesis"));
				  missing_parent = true;
				}
	YY_BREAK

case 12:
YY_RULE_SETUP
#line 164 "scantl.ll"
{
				  if (!lenient_mode)
				  {
				     BEGIN(0);
			             return token::BRACE_OPEN;
                                  }
                                  /* Parse any {...} block as a single block,
				     taking care of nested parentheses.  The
				     parser will then try to parse this block
				     recursively.  */
                                  BEGIN(in_bra);
                                  parent_level = 1;
				  yylval->str = new std::string();
                                }
	YY_BREAK

case 13:
YY_RULE_SETUP
#line 179 "scantl.ll"
{
				  ++parent_level;
				  yylval->str->append(yytext, yyleng);
				}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 183 "scantl.ll"
{
				  if (--parent_level)
				    {
                                      yylval->str->append(yytext, yyleng);
				    }
				  else
				    {
                                      BEGIN(not_prop);
				      spot::trim(*yylval->str);
				      return token::BRA_BANG_BLOCK;
				    }
                                }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 195 "scantl.ll"
{
				  if (--parent_level)
				    {
                                      yylval->str->append(yytext, yyleng);
				    }
				  else
				    {
                                      BEGIN(not_prop);
				      spot::trim(*yylval->str);
				      return token::BRA_BLOCK;
				    }
				}
	YY_BREAK
case 16:
/* rule 16 can match eol */
YY_RULE_SETUP
#line 207 "scantl.ll"
yylval->str->append(yytext, yyleng);
	YY_BREAK
case YY_STATE_EOF(in_bra):
#line 208 "scantl.ll"
{
				  unput('}');
				  if (!missing_parent)
                                    error_list.push_back(
				      spot::one_parse_error(*yylloc,
 					"missing closing brace"));
				  missing_parent = true;
				}
	YY_BREAK

case 17:
YY_RULE_SETUP
#line 218 "scantl.ll"
BEGIN(not_prop); return token::PAR_CLOSE;
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 219 "scantl.ll"
BEGIN(not_prop); return token::BRACE_BANG_CLOSE;
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 220 "scantl.ll"
BEGIN(not_prop); return token::BRACE_CLOSE;
	YY_BREAK
/* Must go before the other operators, because the F of FALSE
     should not be mistaken with a unary F. */
case 20:
YY_RULE_SETUP
#line 224 "scantl.ll"
BEGIN(0); return token::CONST_TRUE;
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 225 "scantl.ll"
BEGIN(0); return token::CONST_FALSE;
	YY_BREAK
/* ~ comes from Goal, ! from everybody else */
case 22:
YY_RULE_SETUP
#line 229 "scantl.ll"
BEGIN(0); return token::OP_NOT;
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 231 "scantl.ll"
BEGIN(0); return token::OP_FIRST_MATCH;
	YY_BREAK
/* SVA operators */
case 24:
YY_RULE_SETUP
#line 234 "scantl.ll"
{
                                  yylval->num = yytext[2] - '0';
                                  return token::OP_DELAY_N;
                                }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 238 "scantl.ll"
{
                                  yylval->num =
                                    yytext[2] * 10 + yytext[3] - '0' * 11;
                                  return token::OP_DELAY_N;
                                }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 243 "scantl.ll"
{
				  errno = 0;
				  unsigned long n = strtoul(yytext + 2, 0, 10);
                                  yylval->num = n;
				  if (errno || yylval->num != n)
				    {
                                      error_list.push_back(
				        spot::one_parse_error(*yylloc,
					  "value too large ignored"));
                                      yylval->num = 1;
                                    }
                                  if (yylval->num >= spot::fnode::unbounded())
                                    {
                                      auto max = spot::fnode::unbounded() - 1;
                                      std::ostringstream s;
                                      s << yylval->num
                                        << (" exceeds maximum supported "
                                            "repetition (")
                                        << max << ")";
                                      error_list.emplace_back(*yylloc, s.str());
                                      yylval->num = max;
                                    }
                                  return token::OP_DELAY_N;
                                }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 267 "scantl.ll"
BEGIN(0); return token::OP_DELAY_PLUS;
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 268 "scantl.ll"
BEGIN(0); return token::OP_DELAY_STAR;
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 269 "scantl.ll"
BEGIN(sqbracket); return token::OP_DELAY_OPEN;
	YY_BREAK
/* PSL operators */
case 30:
YY_RULE_SETUP
#line 272 "scantl.ll"
BEGIN(0); return token::OP_UCONCAT;
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 273 "scantl.ll"
BEGIN(0); return token::OP_ECONCAT;
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 274 "scantl.ll"
BEGIN(0); return token::OP_UCONCAT_NONO;
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 275 "scantl.ll"
BEGIN(0); return token::OP_ECONCAT_NONO;
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 276 "scantl.ll"
BEGIN(0); return token::OP_CONCAT;
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 277 "scantl.ll"
BEGIN(0); return token::OP_FUSION;
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 278 "scantl.ll"
BEGIN(0); return token::OP_STAR;
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 279 "scantl.ll"
BEGIN(0); return token::OP_BSTAR;
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 280 "scantl.ll"
BEGIN(0); return token::OP_PLUS;
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 281 "scantl.ll"
BEGIN(sqbracket); return token::OP_STAR_OPEN;
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 282 "scantl.ll"
BEGIN(0); return token::OP_BFSTAR;
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 283 "scantl.ll"
BEGIN(0); return token::OP_FPLUS;
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 284 "scantl.ll"
BEGIN(sqbracket); return token::OP_FSTAR_OPEN;
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 285 "scantl.ll"
BEGIN(sqbracket); return token::OP_EQUAL_OPEN;
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 286 "scantl.ll"
BEGIN(sqbracket); return token::OP_GOTO_OPEN;
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 287 "scantl.ll"
BEGIN(0); return token::OP_SQBKT_CLOSE;
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 288 "scantl.ll"
BEGIN(0); return token::OP_SQBKT_STRONG_CLOSE;
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 289 "scantl.ll"
{
				  errno = 0;
				  unsigned long n = strtoul(yytext, 0, 10);
                                  yylval->num = n;
				  if (errno || yylval->num != n)
				    {
                                      error_list.push_back(
				        spot::one_parse_error(*yylloc,
					  "value too large ignored"));
				      // Skip this number and read next token
                                      yylloc->step();
                                    }
				  else
                                    {
                                      return token::OP_SQBKT_NUM;
                                    }
				}
	YY_BREAK
/* .. is from PSL and EDL
   : is from Verilog and PSL
   to is from VHDL
   , is from Perl */
case 48:
YY_RULE_SETUP
#line 310 "scantl.ll"
return token::OP_SQBKT_SEP;
	YY_BREAK
/* In SVA you use [=1:$] instead of [=1..].  We will also accept
     [=1..$] and [=1:].  The PSL LRM shows examples like [=1:inf]
     instead, so will accept this too.  */
case 49:
YY_RULE_SETUP
#line 315 "scantl.ll"
return token::OP_UNBOUNDED;
	YY_BREAK
/* & and | come from Spin.  && and || from LTL2BA.
     /\, \/, and xor are from LBTT.
     --> and <--> come from Goal.
     +,*,^ are from Wring. */
case 50:
YY_RULE_SETUP
#line 321 "scantl.ll"
BEGIN(0); return token::OP_OR;
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 322 "scantl.ll"
BEGIN(0); return token::OP_AND;
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 323 "scantl.ll"
BEGIN(0); return token::OP_SHORT_AND;
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 324 "scantl.ll"
BEGIN(0); return token::OP_XOR;
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 325 "scantl.ll"
BEGIN(0); return token::OP_IMPLIES;
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 326 "scantl.ll"
BEGIN(0); return token::OP_EQUIV;
	YY_BREAK
/* TSLF-like syntactic sugar:
    X[3]f = XXXf
    F[2..4]f = XX(f | X(f | Xf))
    G[2..4]f = XX(f & X(f & Xf))
    We also have to deal with the Spin-like notation for G.
    X[]f = XGf
 */
case 56:
/* rule 56 can match eol */
YY_RULE_SETUP
#line 335 "scantl.ll"
yyless(1); return token::OP_X;
	YY_BREAK
case 57:
/* rule 57 can match eol */
YY_RULE_SETUP
#line 336 "scantl.ll"
yyless(1); return token::OP_F;
	YY_BREAK
case 58:
/* rule 58 can match eol */
YY_RULE_SETUP
#line 337 "scantl.ll"
yyless(1); return token::OP_G;
	YY_BREAK
case 59:
/* rule 59 can match eol */
YY_RULE_SETUP
#line 338 "scantl.ll"
BEGIN(sqbracket); return token::OP_XREP;
	YY_BREAK
case 60:
/* rule 60 can match eol */
YY_RULE_SETUP
#line 339 "scantl.ll"
BEGIN(sqbracket); return token::OP_FREP;
	YY_BREAK
case 61:
/* rule 61 can match eol */
YY_RULE_SETUP
#line 340 "scantl.ll"
BEGIN(sqbracket); return token::OP_GREP;
	YY_BREAK
/* <> (DIAMOND) and [] (BOX), are used in Spin.
     () (CIRCLE) is not, but would make sense.  */
case 62:
YY_RULE_SETUP
#line 343 "scantl.ll"
BEGIN(0); return token::OP_F;
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 344 "scantl.ll"
BEGIN(0); return token::OP_G;
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 345 "scantl.ll"
BEGIN(0); return token::OP_U;
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 346 "scantl.ll"
BEGIN(0); return token::OP_R;
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 347 "scantl.ll"
BEGIN(0); return token::OP_X;
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 348 "scantl.ll"
BEGIN(0); return token::OP_STRONG_X;
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 349 "scantl.ll"
BEGIN(0); return token::OP_W;
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 350 "scantl.ll"
BEGIN(0); return token::OP_M;
	YY_BREAK
/* The combining overline or macron (overbar) should normally
     occur only after a single letter, but we do not check that. */
case 70:
YY_RULE_SETUP
#line 354 "scantl.ll"
return token::OP_POST_NEG;
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 355 "scantl.ll"
return token::OP_POST_POS;
	YY_BREAK
case 72:
/* rule 72 can match eol */
YY_RULE_SETUP
#line 357 "scantl.ll"
/* discard whitespace */ yylloc->step ();
	YY_BREAK
/* An Atomic proposition cannot start with the letter
     used by a unary operator (F,G,X), unless this
     letter is followed by a digit in which case we assume
     it's an ATOMIC_PROP (even though F0 could be seen as Ffalse, we
     don't, because Ffalse is never used in practice).
  */
case 73:
#line 366 "scantl.ll"
case 74:
#line 367 "scantl.ll"
/*
     However if we have just parsed an atomic proposition, then we are
     not expecting another atomic proposition, so we can be stricter
     and disallow propositions that start with M, U, R, V, and W.  If
     you wonder why we do this, consider the Wring formula `p=0Uq=1'.
     When p is parsed, we enter the not_prop start condition, we
     remain into this condition when `=0' is processed, and then
     because we are in this condition we will not consider `Uq' as an
     atomic proposition but as a `U' operator followed by a `q' atomic
     proposition.

     We also disable atomic proposition that may look like a combination
     of a binary operator followed by several unary operators.
     E.g. UFXp.   This way, `p=0UFXp=1' will be parsed as `(p=0)U(F(X(p=1)))'.
  */
case 75:
#line 383 "scantl.ll"
case 76:
YY_RULE_SETUP
#line 383 "scantl.ll"
{
			  yylval->str = new std::string(yytext, yyleng);
			  BEGIN(not_prop);
			  return token::ATOMIC_PROP;
			}
	YY_BREAK
/* Atomic propositions can also be enclosed in double quotes.

     orig_cond stores the parsing condition to use after the
     string has been parsed. */
case 77:
YY_RULE_SETUP
#line 393 "scantl.ll"
{
                          orig_cond = not_prop;
			  BEGIN(in_STRING);
			}
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 397 "scantl.ll"
{
			  orig_cond = lbt;
			  BEGIN(in_STRING);
			}
	YY_BREAK

case 79:
YY_RULE_SETUP
#line 403 "scantl.ll"
{
                           BEGIN(orig_cond);
			   yylval->str = new std::string(s);
			   return token::ATOMIC_PROP;
 			}
	YY_BREAK
case 80:
/* rule 80 can match eol */
YY_RULE_SETUP
#line 408 "scantl.ll"
{
  			  s.append(yytext, yyleng);
                          yylloc->lines(yyleng); yylloc->end.column = 1;
			}
	YY_BREAK
case 81:
/* rule 81 can match eol */
YY_RULE_SETUP
#line 412 "scantl.ll"
{
  			  s.append(yytext, yyleng);
                          yylloc->lines(yyleng / 2); yylloc->end.column = 1;
			}
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 416 "scantl.ll"
s += yytext[1];
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 417 "scantl.ll"
s.append(yytext, yyleng);
	YY_BREAK
case YY_STATE_EOF(in_STRING):
#line 418 "scantl.ll"
{
                           error_list.push_back(
			     spot::one_parse_error(*yylloc,
			       "unclosed string"));
                           BEGIN(orig_cond);
			   yylval->str = new std::string(s);
			   return token::ATOMIC_PROP;
                        }
	YY_BREAK

/* these are operators */
case 84:
YY_RULE_SETUP
#line 429 "scantl.ll"
return *yytext;
	YY_BREAK
/* in LBT's format, atomic proposition look like p0 or p3141592, but
     for compatibility with ltl2dstar we also accept any alphanumeric
     string that is not an operator. */
case 85:
YY_RULE_SETUP
#line 433 "scantl.ll"
{
			  yylval->str = new std::string(yytext, yyleng);
			  return token::ATOMIC_PROP;
			}
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 439 "scantl.ll"
return *yytext;
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(not_prop):
case YY_STATE_EOF(sqbracket):
case YY_STATE_EOF(lbt):
#line 441 "scantl.ll"
return token::END_OF_INPUT;
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 443 "scantl.ll"
ECHO;
	YY_BREAK
#line 2049 "scantl.cc"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 286 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 286 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 285);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

    static void yyunput (int c, char * yy_bp )
{
	char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		int number_to_move = (yy_n_chars) + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = (int) YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

    static void yy_push_state (int  _new_state )
{
    	if ( (yy_start_stack_ptr) >= (yy_start_stack_depth) )
		{
		yy_size_t new_size;

		(yy_start_stack_depth) += YY_START_STACK_INCR;
		new_size = (yy_size_t) (yy_start_stack_depth) * sizeof( int );

		if ( ! (yy_start_stack) )
			(yy_start_stack) = (int *) yyalloc( new_size  );

		else
			(yy_start_stack) = (int *) yyrealloc(
					(void *) (yy_start_stack), new_size  );

		if ( ! (yy_start_stack) )
			YY_FATAL_ERROR( "out of memory expanding start-condition stack" );
		}

	(yy_start_stack)[(yy_start_stack_ptr)++] = YY_START;

	BEGIN(_new_state);
}

    static void yy_pop_state  (void)
{
    	if ( --(yy_start_stack_ptr) < 0 )
		YY_FATAL_ERROR( "start-condition stack underflow" );

	BEGIN((yy_start_stack)[(yy_start_stack_ptr)]);
}

    static int yy_top_state  (void)
{
    	return (yy_start_stack)[(yy_start_stack_ptr) - 1];
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_start_stack_ptr) = 0;
    (yy_start_stack_depth) = 0;
    (yy_start_stack) =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Destroy the start condition stack. */
        yyfree( (yy_start_stack)  );
        (yy_start_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 443 "scantl.ll"


void
flex_set_buffer(const std::string& buf,
		int start_tok, bool lenient)
{
  yypush_buffer_state(YY_CURRENT_BUFFER);
  (void) yy_scan_bytes(buf.c_str(), buf.size());
  start_token = start_tok;
  if (start_tok == token::START_LBT)
    yy_push_state(lbt);
  else
    yy_push_state(0);
  lenient_mode = lenient;
}

void
flex_unset_buffer()
{
  (void)&yy_top_state; // shut up a g++ warning.
  yy_pop_state();
  yypop_buffer_state();
  missing_parent = false;
}

